namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.EcopediaRoot;

    [Serialized]
	[LocDisplayName("Cedar Planked Fish")]
    [Weight(500)]
	[Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class CedarPlankedFishItem : FoodItem
    {
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("Fish cooked with herbs on a cedar plank."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 0, Fat = 7, Protein = 15, Vitamins = 5};
        public override float Calories                          { get { return 1800; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 2)]
    public partial class CedarPlankedFishRecipe : RecipeFamily
    {
        public CedarPlankedFishRecipe()
        {
            var product = new Recipe(
				"CedarPlankedFish",
				Localizer.DoStr("Cedar Planked Fish"),
				new IngredientElement[]
				{
					new IngredientElement(typeof(FishFiletItem), 2, typeof(AdvancedCookingSkill), typeof (AdvancedCookingLavishResourcesTalent)),
					new IngredientElement(typeof(PlantFibersItem), 4, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
					new IngredientElement("WoodBoard", 2, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
				},
				new CraftingElement<CedarPlankedFishItem>(1)
			);
			this.Initialize(Localizer.DoStr("Cedar Planked Fish"), typeof(CedarPlankedFishRecipe));
			this.Recipes = new List<Recipe> { product };
			this.LaborInCalories = CreateLaborInCaloriesValue(20, typeof(AdvancedCookingSkill), typeof(CedarPlankedFishRecipe), this.UILink());
			this.CraftMinutes = CreateCraftTimeValue(typeof(CedarPlankedFishRecipe), this.UILink(), 5, typeof(AdvancedCookingSkill), typeof(AdvancedCookingFocusedSpeedTalent), typeof(AdvancedCookingParallelSpeedTalent)); 
			this.Initialize(Localizer.DoStr("Cedar Planked Fish"), typeof(CedarPlankedFishRecipe));
			CraftingComponent.AddRecipe(typeof(StoveObject), this);
        }
    }
}