namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.EcopediaRoot;

    [Serialized]
	[LocDisplayName("Clam with Tomato Sauce and Rice")]
    [Weight(500)]
	[Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class ClamRiceItem : FoodItem
    {
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("Tasty Clams with Tomato-Rice Sauce."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 5, Fat = 15, Protein = 13, Vitamins = 10};
        public override float Calories                          { get { return 1200; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 4)]
    public partial class ClamRiceRecipe : RecipeFamily
    {
        public ClamRiceRecipe()
        {
			var product = new Recipe(
				"ClamRice",
				Localizer.DoStr("Clam with Tomato Sauce and Rice"),
				new IngredientElement[]
				{
					new IngredientElement(typeof(ClamItem), 2, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
					new IngredientElement(typeof(TomatoSauceItem), 1, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
					new IngredientElement(typeof(RiceItem), 2, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
					new IngredientElement(typeof(InfusedOilItem), 1, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
				},
				new CraftingElement<ClamRiceItem>(1)
			);                
			this.Initialize(Localizer.DoStr("Clam with Tomato Sauce and Rice"), typeof(ClamRiceRecipe));
			this.Recipes = new List<Recipe> { product };
			this.LaborInCalories = CreateLaborInCaloriesValue(20, typeof(AdvancedCookingSkill), typeof(ClamRiceRecipe), this.UILink());
			this.CraftMinutes = CreateCraftTimeValue(typeof(ClamRiceRecipe), this.UILink(), 20, typeof(AdvancedCookingSkill), typeof(AdvancedCookingFocusedSpeedTalent), typeof(AdvancedCookingParallelSpeedTalent)); 
			this.Initialize(Localizer.DoStr("Clam with Tomato Sauce and Rice"), typeof(ClamRiceRecipe));
			CraftingComponent.AddRecipe(typeof(StoveObject), this);
        }
    }
}