namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.EcopediaRoot;

    [Serialized]
	[LocDisplayName("Fish with bread")]
    [Weight(100)]
	[Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class FishBreadItem : FoodItem
    {
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("A Simple piece of fish with bannock."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 9, Fat = 6, Protein = 5, Vitamins = 3};
        public override float Calories                          { get { return 550; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(CookingSkill), 1)]
    public partial class FishBreadRecipe : RecipeFamily
    {
        public FishBreadRecipe()
        {
            var product = new Recipe(
				"FishBread",
				Localizer.DoStr("Fish with bread"),
				new IngredientElement[]
				{
					new IngredientElement(typeof(BannockItem), 4, typeof(CookingSkill), typeof(CookingLavishResourcesTalent)),
					new IngredientElement(typeof(FishFiletItem), 4, typeof(CookingSkill), typeof(CookingLavishResourcesTalent)),
				},
				new CraftingElement<FishBreadItem>(1)
            );
			this.Initialize(Localizer.DoStr("Fish with bread"), typeof(FishBreadRecipe));
			this.Recipes = new List<Recipe> { product };
			this.LaborInCalories = CreateLaborInCaloriesValue(20, typeof(CookingSkill), typeof(FishBreadRecipe), this.UILink());
			this.CraftMinutes = CreateCraftTimeValue(typeof(FishBreadRecipe), this.UILink(), 5, typeof(CookingSkill), typeof(CookingFocusedSpeedTalent), typeof(CookingParallelSpeedTalent));
			this.Initialize(Localizer.DoStr("Fish Bread"), typeof(FishBreadRecipe));
            CraftingComponent.AddRecipe(typeof(KitchenObject), this);
        }
    }
}