namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.EcopediaRoot;
    
    [Serialized]
	[LocDisplayName("Fish Curry")]
    [Weight(900)]
	[Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class FishCurryItem : FoodItem
    {
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("A Sharp Fishly Curry"); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 14, Fat = 12, Protein = 10, Vitamins = 9};
        public override float Calories                          { get { return 900; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 3)]
    public partial class FishCurryRecipe : RecipeFamily
    {
        public FishCurryRecipe()
        {
            var product = new Recipe(
				"FishCurry",
				Localizer.DoStr("Fish Curry"),
				new IngredientElement[]
				{
					new IngredientElement(typeof(FishFiletItem), 10, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)), 
					new IngredientElement(typeof(FlourItem), 1, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)), 
					new IngredientElement(typeof(RiceItem), 15, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)), 
					new IngredientElement(typeof(InfusedOilItem), 2, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)), 
					new IngredientElement("Vegetable", 6, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)), 
				},
				new CraftingElement<FishCurryItem>(1)
            );
            this.Initialize(Localizer.DoStr("Fish Curry"), typeof(FishCurryRecipe));
			this.Recipes = new List<Recipe> { product };
			this.LaborInCalories = CreateLaborInCaloriesValue(20, typeof(AdvancedCookingSkill), typeof(FishCurryRecipe), this.UILink());
			this.CraftMinutes = CreateCraftTimeValue(typeof(FishCurryRecipe), this.UILink(), 10, typeof(AdvancedCookingSkill), typeof(AdvancedCookingFocusedSpeedTalent), typeof(AdvancedCookingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Fish Curry"), typeof(FishCurryRecipe));
            CraftingComponent.AddRecipe(typeof(KitchenObject), this);
        }
    }
}