namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.EcopediaRoot;

    [Serialized]
	[LocDisplayName("Fish Filet")]
    [Weight(500)]
	[Ecopedia("Food", "Ingredients", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class FishFiletItem : FoodItem
    {
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("A filet of fish, ready to be cooked in to a delicious dish."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 0, Fat = 9, Protein = 13, Vitamins = 0};
        public override float Calories                          { get { return 550; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(CookingSkill), 1)]
    public partial class FishFiletRecipe : RecipeFamily
    {
        public FishFiletRecipe()
        {
            var product = new Recipe(
				"Fish Filet",
				Localizer.DoStr("Fish Filet"),
				new IngredientElement[]
				{
					new IngredientElement(typeof(RawFishItem), 1, typeof(CookingSkill), typeof(CookingLavishResourcesTalent)),
				},
				new CraftingElement<FishFiletItem>(1)
				
			);
			this.Initialize(Localizer.DoStr("Fish Filet"), typeof(FishFiletRecipe));
			this.Recipes = new List<Recipe> { product };
			this.LaborInCalories = CreateLaborInCaloriesValue(20, typeof(CookingSkill), typeof(FishFiletRecipe), this.UILink()); 
			this.CraftMinutes = CreateCraftTimeValue(typeof(FishFiletRecipe), this.UILink(), 5, typeof(CookingSkill), typeof(CookingFocusedSpeedTalent), typeof(CookingParallelSpeedTalent));
			this.Initialize(Localizer.DoStr("Fish Filet"), typeof(FishFiletRecipe));
            CraftingComponent.AddRecipe(typeof(KitchenObject), this);
        }
    }
}