namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.EcopediaRoot;

    
    [Serialized]
	[LocDisplayName("Fish Kebab")]
    [Weight(500)]
	[Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class FishKebabItem : FoodItem
    {
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("Cooked fish on a kebab."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 0, Fat = 8, Protein = 6, Vitamins = 6};
        public override float Calories							{ get { return 600; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(CampfireCookingSkill), 3)]    
    public partial class FishKebabRecipe : RecipeFamily
    {
        public FishKebabRecipe()
        {
            var product = new Recipe(
				"FishKebab",
				Localizer.DoStr("Fish Kebab"),
				new IngredientElement[]
				{
					new IngredientElement(typeof(RawFishItem), 6, typeof(CampfireCookingSkill), typeof(CampfireCookingLavishResourcesTalent)),
					new IngredientElement("Vegetable", 4, typeof(CampfireCookingSkill), typeof(CampfireCookingLavishResourcesTalent)),
					new IngredientElement(typeof(WoodPulpItem), 1, typeof(CampfireCookingSkill), typeof(CampfireCookingLavishResourcesTalent)),
				},
				new CraftingElement<FishKebabItem>(1)
			);
			this.Initialize(Localizer.DoStr("Fish Kebab"), typeof(FishKebabRecipe));
			this.Recipes = new List<Recipe> { product };
			this.LaborInCalories = CreateLaborInCaloriesValue(20, typeof(CampfireCookingSkill), typeof(FishKebabRecipe), this.UILink());
			this.CraftMinutes = CreateCraftTimeValue(typeof(FishKebabRecipe), this.UILink(), 5, typeof(CampfireCookingSkill), typeof(CampfireCookingFocusedSpeedTalent), typeof(CampfireCookingParallelSpeedTalent));
			this.Initialize(Localizer.DoStr("Fish Kebab"), typeof(FishKebabRecipe));
            CraftingComponent.AddRecipe(typeof(CampfireObject), this);
        }
    }
}