namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.EcopediaRoot;
    
    [Serialized]
	[LocDisplayName("Fish Stew")]
    [Weight(500)]                                          
	[Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class FishStewItem : FoodItem
    {
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("Fish, herbs, and various vegetables cooked in to a stew."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 10, Fat = 11, Protein = 11, Vitamins = 8};
        public override float Calories                          { get { return 1400; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(CampfireCookingSkill), 4)]    
    public partial class FishStewRecipe : RecipeFamily
    {
        public FishStewRecipe()
        {
            var product = new Recipe(
				"FishStew",
				Localizer.DoStr("Fish Stew"),
				new IngredientElement[]
				{
					new IngredientElement(typeof(RawFishItem), 10, typeof(CampfireCookingSkill), typeof(CampfireCookingLavishResourcesTalent)),
					new IngredientElement(typeof(AcornPowderItem), 3, typeof(CampfireCookingSkill), typeof(CampfireCookingLavishResourcesTalent)),
					new IngredientElement("Vegetable", 16, typeof(CampfireCookingSkill), typeof(CampfireCookingLavishResourcesTalent)),
				},
				new CraftingElement<FishStewItem>(1)
			);
			this.Initialize(Localizer.DoStr("Fish Stew"), typeof(FishStewRecipe));
			this.Recipes = new List<Recipe> { product };
			this.LaborInCalories = CreateLaborInCaloriesValue(20, typeof(CampfireCookingSkill), typeof(FishStewRecipe), this.UILink());
            this.CraftMinutes = CreateCraftTimeValue(typeof(FishStewRecipe), this.UILink(), 5, typeof(CampfireCookingSkill), typeof(CampfireCookingFocusedSpeedTalent), typeof(CampfireCookingParallelSpeedTalent)); 
            this.Initialize(Localizer.DoStr("Fish Stew"), typeof(FishStewRecipe));
            CraftingComponent.AddRecipe(typeof(CampfireObject), this);
        }
    }
}