namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.EcopediaRoot;
    
    [Serialized]
	[LocDisplayName("Fish Tacos")]
    [Weight(500)]                                          
	[Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class FishTacosItem : FoodItem
    {
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("Tacos, but with fish!"); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 15, Fat = 5, Protein = 3, Vitamins = 7};
        public override float Calories                          { get { return 1500; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 1)]    
    public partial class FishTacosRecipe : RecipeFamily
    {
		public FishTacosRecipe()
		{
			
			var product = new Recipe(
				"FishTacos",
				Localizer.DoStr("Fish Tacos"),
				new IngredientElement[]
				{
					new IngredientElement(typeof(RawFishItem), 4, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
					new IngredientElement(typeof(FlatbreadItem), 4, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
					new IngredientElement("Greens", 4, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
				},
				new CraftingElement<FishTacosItem>(1)
			);
		this.Initialize(Localizer.DoStr("Fish Tacos"), typeof(FishTacosRecipe));
		this.Recipes = new List<Recipe> { product };
		this.LaborInCalories = CreateLaborInCaloriesValue(20, typeof(AdvancedCookingSkill), typeof(FishTacosRecipe), this.UILink());
        this.CraftMinutes = CreateCraftTimeValue(typeof(FishTacosRecipe), this.UILink(), 5, typeof(AdvancedCookingSkill), typeof(AdvancedCookingFocusedSpeedTalent), typeof(AdvancedCookingParallelSpeedTalent)); 
        this.Initialize(Localizer.DoStr("Fish Tacos"), typeof(FishTacosRecipe));
        CraftingComponent.AddRecipe(typeof(CastIronStoveObject), this);
        }
    }
}