namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.EcopediaRoot;
    
    [Serialized]
	[LocDisplayName("Fish with Vegetables")]
    [Weight(500)]                                          
	[Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class FishWithVegetablesItem : FoodItem
    {
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("Fish, herbs, and beans."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 6, Fat = 13, Protein = 14, Vitamins = 4};
        public override float Calories                          { get { return 1500; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 3)]    
    public partial class FishWithVegetablesRecipe : RecipeFamily
    {
        public FishWithVegetablesRecipe()
        {
            var product = new Recipe(
				"FishWithVegetables",
				Localizer.DoStr("Fish with Vegetables"),
				new IngredientElement[]
				{
					new IngredientElement(typeof(FishFiletItem), 6, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
					new IngredientElement(typeof(BeansItem), 4, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
					new IngredientElement(typeof(OilItem), 1, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
				},
				new CraftingElement<FishWithVegetablesItem>(1)
            );
			this.Initialize(Localizer.DoStr("Fish with Vegetables"), typeof(FishWithVegetablesRecipe));
			this.Recipes = new List<Recipe> { product };
			this.LaborInCalories = CreateLaborInCaloriesValue(20, typeof(AdvancedCookingSkill), typeof(FishWithVegetablesRecipe), this.UILink());
            this.CraftMinutes = CreateCraftTimeValue(typeof(FishWithVegetablesRecipe), this.UILink(), 5, typeof(AdvancedCookingSkill), typeof(AdvancedCookingFocusedSpeedTalent), typeof(AdvancedCookingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Fish With Vegetables"), typeof(FishWithVegetablesRecipe));
            CraftingComponent.AddRecipe(typeof(CastIronStoveObject), this);
        }
    }
}