namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.EcopediaRoot;

    
    [Serialized]
	[LocDisplayName("Fish n' Chips")]
    [Weight(900)]
	[Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class FishnChipsItem : FoodItem
    {
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("A tasty combination of breaded fish and camas bulb chips."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 12, Fat = 10, Protein = 7, Vitamins = 5};
        public override float Calories                          { get { return 1200; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 3)]
    public partial class FishnChipsRecipe : RecipeFamily
    {
        public FishnChipsRecipe()
        {
            var product = new Recipe(
				"FishnChips",
				Localizer.DoStr("Fish n' Chips"),
				new IngredientElement[]
				{
					new IngredientElement(typeof(FishFiletItem), 4, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
					new IngredientElement(typeof(FlourItem), 1, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
					new IngredientElement(typeof(CamasBulbItem), 2, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
				},
				new CraftingElement<FishnChipsItem>(1)
			);
			this.Initialize(Localizer.DoStr("Fish n' Chips"), typeof(FishnChipsRecipe));
			this.Recipes = new List<Recipe> { product };
			this.LaborInCalories = CreateLaborInCaloriesValue(20, typeof(AdvancedCookingSkill), typeof(FishnChipsRecipe), this.UILink());
			this.CraftMinutes = CreateCraftTimeValue(typeof(FishnChipsRecipe), this.UILink(), 5, typeof(AdvancedCookingSkill), typeof(AdvancedCookingFocusedSpeedTalent), typeof(AdvancedCookingParallelSpeedTalent));
			this.Initialize(Localizer.DoStr("Fish n' Chips"), typeof(FishnChipsRecipe));
            CraftingComponent.AddRecipe(typeof(CastIronStoveObject), this);
        }
    }
}