namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.EcopediaRoot;

    [Serialized]
	[LocDisplayName("Fried Fish and Wan-Tan")]
    [Weight(900)]                                          
	[Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class FriedFishItem : FoodItem
    {
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("Fried Fish with Sweet Camas and Wan-Tan"); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 15, Fat = 10, Protein = 8, Vitamins = 9};
        public override float Calories                          { get { return 900; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 3)]    
    public partial class FriedFishRecipe : RecipeFamily
    {
        public FriedFishRecipe()
        {
            var product = new Recipe(
			"FriedFishandWanTan",
			Localizer.DoStr("Fried Fish and Wan-Tan"),
			new IngredientElement[]
            {
				new IngredientElement(typeof(FishFiletItem), 6, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
				new IngredientElement(typeof(FlourItem), 4, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
				new IngredientElement(typeof(CamasBulbItem), 2, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
				new IngredientElement(typeof(OilItem), 1, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
				new IngredientElement(typeof(CornmealItem), 2, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
			},
			new CraftingElement<FriedFishItem>(1)
			);
			this.Initialize(Localizer.DoStr("Fried Fish and Wan-Tan"), typeof(FriedFishRecipe));
            this.Recipes = new List<Recipe> { product };
			this.LaborInCalories = CreateLaborInCaloriesValue(20,typeof(AdvancedCookingSkill), typeof(FriedFishRecipe), this.UILink());
			this.CraftMinutes = CreateCraftTimeValue(typeof(FriedFishRecipe), this.UILink(), 10, typeof(AdvancedCookingSkill), typeof(AdvancedCookingFocusedSpeedTalent), typeof(AdvancedCookingParallelSpeedTalent));
            this.Initialize(Localizer.DoStr("Fried Fish and Wan-Tan"), typeof(FriedFishRecipe));
            CraftingComponent.AddRecipe(typeof(KitchenObject), this);
        }
    }
}