namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.EcopediaRoot;
    
    [Serialized]
	[LocDisplayName("Okanagan Green Beans")]
    [Weight(500)]                                          
	[Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class OkanaganGreenBeanItem : FoodItem
    {
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("Fish, herbs, and beans."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 8, Fat = 15, Protein = 15, Vitamins = 3};
        public override float Calories                          { get { return 1500; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 3)]    
    public partial class OkanaganGreenBeanRecipe : RecipeFamily
    {
        public OkanaganGreenBeanRecipe()
        {
            var product = new Recipe(
				"OkanaganGreenBeans",
				Localizer.DoStr("Okanagan Green Beans"),
				new IngredientElement[]				
				{
					new IngredientElement(typeof(FishFiletItem), 4, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)), 
					new IngredientElement(typeof(BeansItem), 4, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)), 
					new IngredientElement(typeof(PlantFibersItem), 2, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)), 
				},
				new CraftingElement<OkanaganGreenBeanItem>(1)
			);
			this.Initialize(Localizer.DoStr("Okanagan Green Beans"), typeof(OkanaganGreenBeanRecipe));
			this.Recipes = new List<Recipe> { product };
			this.LaborInCalories = CreateLaborInCaloriesValue(20, typeof(AdvancedCookingSkill), typeof(OkanaganGreenBeanRecipe), this.UILink());
            this.CraftMinutes = CreateCraftTimeValue(typeof(OkanaganGreenBeanRecipe), this.UILink(), 5, typeof(AdvancedCookingSkill), typeof(AdvancedCookingFocusedSpeedTalent), typeof(AdvancedCookingParallelSpeedTalent)); 
            this.Initialize(Localizer.DoStr("Okanagan Green Beans"), typeof(OkanaganGreenBeanRecipe));
            CraftingComponent.AddRecipe(typeof(CastIronStoveObject), this);
        }
    }
}