namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.EcopediaRoot;
    
    [Serialized]
	[LocDisplayName("Poached Fish")]
    [Weight(500)]                                          
	[Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class PoachedFishItem : FoodItem
    {
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("Poached Fish."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 6, Fat = 12, Protein = 18, Vitamins = 6};
        public override float Calories                          { get { return 1500; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 1)]    
    public partial class PoachedFishRecipe : RecipeFamily
    {
        public PoachedFishRecipe()
        {
            var product = new Recipe(
				"PoachedFish",
				Localizer.DoStr("Poached Fish"),
				new IngredientElement[]
				{
					new IngredientElement(typeof(FishFiletItem), 4, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
					new IngredientElement(typeof(TallowItem), 2, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
					new IngredientElement(typeof(PlantFibersItem), 1, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
					new IngredientElement(typeof(TomatoItem), 2, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)),
				},
				new CraftingElement<PoachedFishItem>(1)
			);
			this.Initialize(Localizer.DoStr("Poached Fish"), typeof(PoachedFishRecipe));
			this.Recipes = new List<Recipe> { product };
			this.LaborInCalories = CreateLaborInCaloriesValue(20, typeof(AdvancedCookingSkill), typeof(PoachedFishRecipe), this.UILink());
            this.CraftMinutes = CreateCraftTimeValue(typeof(PoachedFishRecipe), this.UILink(), 5, typeof(AdvancedCookingSkill), typeof(AdvancedCookingFocusedSpeedTalent), typeof(AdvancedCookingParallelSpeedTalent));  
            this.Initialize(Localizer.DoStr("Poached Fish"), typeof(PoachedFishRecipe));
            CraftingComponent.AddRecipe(typeof(CastIronStoveObject), this);
        }
    }
}