namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.EcopediaRoot;
    
    [Serialized]
	[LocDisplayName("Sushi with Rice")]
    [Weight(100)]                                          
	[Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class SushiRiceItem : FoodItem
    {
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("A Tasty Raw Fish Meal with Rice"); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 0, Fat = 6, Protein = 5, Vitamins = 4};
        public override float Calories                          { get { return 470; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(CampfireCookingSkill), 0)]
    public partial class SushiRiceRecipe : RecipeFamily
    {
        public SushiRiceRecipe()
        {
			var product = new Recipe(
				"SushiWithRice",
				Localizer.DoStr("Sushi with Rice"),
				new IngredientElement[]
				{
					new IngredientElement(typeof(BeetItem), 1, typeof(CampfireCookingSkill), typeof(CampfireCookingLavishResourcesTalent)),
					new IngredientElement(typeof(RawFishItem), 1, typeof(CampfireCookingSkill), typeof(CampfireCookingLavishResourcesTalent)),
					new IngredientElement(typeof(RiceItem), 1, typeof(CampfireCookingSkill), typeof(CampfireCookingLavishResourcesTalent)),
				},
				new CraftingElement<SushiRiceItem>(1)
			);
            this.Initialize(Localizer.DoStr("Sushi with Rice"), typeof(SushiRiceRecipe));
			this.Recipes = new List<Recipe> { product };
			this.LaborInCalories = CreateLaborInCaloriesValue(10, typeof(CampfireCookingSkill), typeof(CharredFishRecipe), this.UILink()); 
			this.CraftMinutes = CreateCraftTimeValue(typeof(SushiRiceRecipe), this.UILink(), 1, typeof(CampfireCookingSkill), typeof(CampfireCookingFocusedSpeedTalent), typeof(CampfireCookingParallelSpeedTalent));     
            this.Initialize(Localizer.DoStr("Sushi Rice"), typeof(SushiRiceRecipe));
            CraftingComponent.AddRecipe(typeof(CampfireObject), this);
        }
    }
}