namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.EcopediaRoot;

    [Serialized]
	[LocDisplayName("Sushi with Urchins")]
    [Weight(900)]                                          
	[Ecopedia("Food", "Cooking", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class SushiUrchinItem : FoodItem
    {
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("A Tasty Sushi mix with Urchins"); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 12, Fat = 8, Protein = 9, Vitamins = 13};
        public override float Calories                          { get { return 1200; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 3)]    
    public partial class SushiUrchinRecipe : RecipeFamily
    {
        public SushiUrchinRecipe()
        {
            var product = new Recipe(
				"SushiWithUrchins",
				Localizer.DoStr("Sushi with Urchins"),
				new IngredientElement[]
				{
					new IngredientElement(typeof(FishFiletItem), 4, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)), 
					new IngredientElement(typeof(UrchinItem), 2, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)), 
					new IngredientElement(typeof(RiceItem), 4, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)), 
					new IngredientElement(typeof(KelpItem), 2, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)), 
					new IngredientElement("Vegetable", 2,typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)), 
				},
				new CraftingElement<SushiUrchinItem>(1)
			);
			this.Initialize(Localizer.DoStr("Sushi with Urchins"), typeof(SushiUrchinRecipe));
			this.Recipes = new List<Recipe> { product };
			this.LaborInCalories = CreateLaborInCaloriesValue(20, typeof(AdvancedCookingSkill), typeof(SushiUrchinRecipe), this.UILink());
            this.CraftMinutes = CreateCraftTimeValue(typeof(SushiUrchinRecipe), this.UILink(), 10, typeof(AdvancedCookingSkill), typeof(AdvancedCookingFocusedSpeedTalent), typeof(AdvancedCookingParallelSpeedTalent));    
            this.Initialize(Localizer.DoStr("Sushi with Urchins"), typeof(SushiUrchinRecipe));
            CraftingComponent.AddRecipe(typeof(CastIronStoveObject), this);
        }
    }
}