namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using Eco.Core.Items;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
    using Eco.Gameplay.Objects;
    using Eco.Gameplay.EcopediaRoot;
    
    [Serialized]
	[LocDisplayName("Tomato Sauce")]
    [Weight(500)]                                          
	[Ecopedia("Food", "Ingredients", createAsSubPage: true, display: InPageTooltip.DynamicTooltip)]
    public partial class TomatoSauceItem : FoodItem
    {
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("A Simple Tasty Tomato Sauce."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 5, Fat = 5, Protein = 4, Vitamins = 17};
        public override float Calories                          { get { return 550; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(AdvancedCookingSkill), 1)]    
    public partial class TomatoSauceRecipe : RecipeFamily
    {
        public TomatoSauceRecipe()
        {
            var product = new Recipe(
				"TomatoSauce",
				Localizer.DoStr("Tomato Sauce"),
				new IngredientElement[]
				{
					new IngredientElement(typeof(TomatoItem), 6, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)), 
					new IngredientElement(typeof(OilItem), 4, typeof(AdvancedCookingSkill), typeof(AdvancedCookingLavishResourcesTalent)), 
				},
				new CraftingElement<TomatoSauceItem>(1)
			);
			this.Initialize(Localizer.DoStr("Tomato Sauce"), typeof(TomatoSauceRecipe));
			this.Recipes = new List<Recipe> { product };
			this.LaborInCalories = CreateLaborInCaloriesValue(20, typeof(AdvancedCookingSkill), typeof(TomatoSauceRecipe), this.UILink());
            this.CraftMinutes = CreateCraftTimeValue(typeof(TomatoSauceRecipe), this.UILink(), 3, typeof(AdvancedCookingSkill), typeof(AdvancedCookingFocusedSpeedTalent), typeof(AdvancedCookingParallelSpeedTalent));    
            this.Initialize(Localizer.DoStr("Tomato Sauce"), typeof(TomatoSauceRecipe));
            CraftingComponent.AddRecipe(typeof(KitchenObject), this);
        }
    }
}